<?php
namespace ElementorTeamVision\Widgets;

use \Elementor\Controls_Manager as Controls_Manager;
use \Elementor\Frontend;
use \Elementor\Group_Control_Border as Group_Control_Border;
use \Elementor\Group_Control_Box_Shadow as Group_Control_Box_Shadow;
use \Elementor\Group_Control_Typography as Group_Control_Typography;
use \Elementor\Utils as Utils;
use \Elementor\Widget_Base as Widget_Base;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Team Vision
 *
 * Elementor widget for team vision
 *
 * @since 1.0.0
 */
class Team_Vision_Style6 extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'team-vision-style6';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Team Vision Style 6', 'elementor-team-vision' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-person';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'general' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'elementor-team-vision' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _register_controls() {

  		$this->start_controls_section(
  			'section_settings',
  			[
  				'label' => esc_html__( 'Settings', 'elementor-team-vision' )
  			]
		);

		$this->add_control(
			'columns',
			[
				'label' => esc_html__( 'Columns', 'elementor-team-vision' ),
				'type' => Controls_Manager::SELECT,
				'default' => '2',
				'options' => [
					'1'	=> '1',
					'2' => '2',					
					'3' => '3',					
					'4' => '4'					
				]
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'elementor-team-vision' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

		$this->add_control(
			'custom_style',
			[
				'label' => esc_html__( 'Custom Style', 'elementor-team-vision' ),
				'type' => Controls_Manager::SELECT,
				'default' => 'off',
				'options' => [
					'off'	=> 'Off',
					'on' 	=> 'On'					
				]
			]
		);

		$this->add_control(
			'title_color',
			[
				'label' => esc_html__( 'Title Color', 'elementor-team-vision' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#FFFFFF',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);

		$this->add_control(
			'role_color',
			[
				'label' => esc_html__( 'Role Color', 'elementor-team-vision' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#000000',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);
		
		$this->add_control(
			'social_color',
			[
				'label' => esc_html__( 'Social Color', 'elementor-team-vision' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#FFFFFF',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);

		$this->add_control(
			'h_color',
			[
				'label' => esc_html__( 'Social Hover Color', 'elementor-team-vision' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#333333',
				'condition'	=> [
					'custom_style'	=> 'on'
				]
			]
		);

		$this->end_controls_section();
		
		
		$this->end_controls_section();

		$this->start_controls_section(
			'section_elements',
			[
				'label' => esc_html__( 'Team Members', 'elementor-team-vision' ), // Section display name
			]
		);
		
		$this->add_control(
			'elements',
			[
				'label' => esc_html__( 'Add Member', 'elementor-team-vision' ),
				'type' => Controls_Manager::REPEATER,
				'fields' => [
					[
						'name' => 'image_user',
						'label' => esc_html__( 'Image User Team', 'elementor-team-vision' ),
						'type' => \Elementor\Controls_Manager::MEDIA,
						'label_block' => true						
					],
					[
						'name' => 'name',
						'label' => esc_html__( 'Name', 'elementor-team-vision' ),
						'type' => Controls_Manager::TEXT,
						'label_block' => true					
					],
					[
						'name' => 'role',
						'label' => esc_html__( 'Role', 'elementor-team-vision' ),
						'type' => Controls_Manager::TEXT,
						'label_block' => true					
					],						
					[
						'name' => 'social',
						'label' => esc_html__( 'Social', 'elementor-team-vision' ),
						'type' => Controls_Manager::SELECT,
						'default' => 'on',
						'options' => [
							'on'	=> esc_html__('On','elementor-team-vision'),
							'off' 	=> esc_html__('Off','elementor-team-vision')					
						]
					],						
					[
						'name' => 'social_target',
						'label' => esc_html__( 'Social Target', 'elementor-team-vision' ),
						'type' => Controls_Manager::SELECT,
						'default' => '_blank',
						'options' => [
							'_blank'	=> esc_html__('Blank (new window)','elementor-team-vision'),
							'_self' 	=> esc_html__('Self (Same window)','elementor-team-vision')					
						],
						'label_block' => true,
						'condition'	=> [
							'social'	=> 'on'
						]
					],
					[
						'name' => 'social_icon_1',
						'label' => esc_html__( 'Social Icons', 'elementor-team-vision' ),
						'type' => \Elementor\Controls_Manager::ICON,
						'default' => 'fa fa-facebook',
						'condition'	=> [
							'social'	=> 'on'
						]
					],
					[
						'name' => 'url_social_1',
						'label' => esc_html__( 'Url Social', 'elementor-team-vision' ),
						'type' => Controls_Manager::TEXT,
						'label_block' => true,
						'condition'	=> [
							'social'	=> 'on'
						]					
					],	
					[
						'name' => 'social_icon_2',
						'label' => esc_html__( 'Social Icons 2', 'elementor-team-vision' ),
						'type' => \Elementor\Controls_Manager::ICON,
						'default' => 'fa fa-facebook',
						'condition'	=> [
							'social'	=> 'on'
						]
					],
					[
						'name' => 'url_social_2',
						'label' => esc_html__( 'Url Social 2', 'elementor-team-vision' ),
						'type' => Controls_Manager::TEXT,
						'label_block' => true,
						'condition'	=> [
							'social'	=> 'on'
						]					
					],
					[
						'name' => 'social_icon_3',
						'label' => esc_html__( 'Social Icons 3', 'elementor-team-vision' ),
						'type' => \Elementor\Controls_Manager::ICON,
						'default' => 'fa fa-facebook',
						'condition'	=> [
							'social'	=> 'on'
						]
					],
					[
						'name' => 'url_social_3',
						'label' => esc_html__( 'Url Social 3', 'elementor-team-vision' ),
						'type' => Controls_Manager::TEXT,
						'label_block' => true,
						'condition'	=> [
							'social'	=> 'on'
						]					
					],
					[
						'name' => 'social_icon_4',
						'label' => esc_html__( 'Social Icons 4', 'elementor-team-vision' ),
						'type' => \Elementor\Controls_Manager::ICON,
						'default' => 'fa fa-facebook',
						'condition'	=> [
							'social'	=> 'on'
						]
					],
					[
						'name' => 'url_social_4',
						'label' => esc_html__( 'Url Social', 'elementor-team-vision' ),
						'type' => Controls_Manager::TEXT,
						'label_block' => true,
						'condition'	=> [
							'social'	=> 'on'
						]					
					],
					[
						'name' => 'social_icon_5',
						'label' => esc_html__( 'Social Icons 5', 'elementor-team-vision' ),
						'type' => \Elementor\Controls_Manager::ICON,
						'default' => 'fa fa-facebook',
						'condition'	=> [
							'social'	=> 'on'
						]
					],
					[
						'name' => 'url_social_5',
						'label' => esc_html__( 'Url Social 5', 'elementor-team-vision' ),
						'type' => Controls_Manager::TEXT,
						'label_block' => true,
						'condition'	=> [
							'social'	=> 'on'
						]					
					],					
					[
						'name' => 'addon_animate',
						'label' => esc_html__( 'Animate', 'elementor-team-vision' ),
						'type' => Controls_Manager::SELECT,
						'default' => 'off',
						'options' => [
							'off'	=> 'Off',
							'on' 	=> 'On'					
						]
					],					
					[
						'name' => 'effect',
						'label' => esc_html__( 'Animate Effects', 'elementor-team-vision' ),
						'type' => Controls_Manager::SELECT,
						'default' => 'fade-in',
						'options' => [
							'fade-in'			=> esc_html__( 'Fade In', 'elementor-team-vision' ),
							'fade-in-up' 		=> esc_html__( 'fade in up', 'elementor-team-vision' ),					
							'fade-in-down' 		=> esc_html__( 'fade in down', 'elementor-team-vision' ),					
							'fade-in-left' 		=> esc_html__( 'fade in Left', 'elementor-team-vision' ),					
							'fade-in-right' 	=> esc_html__( 'fade in Right', 'elementor-team-vision' ),					
							'fade-out'			=> esc_html__( 'Fade In', 'elementor-team-vision' ),
							'fade-out-up' 		=> esc_html__( 'Fade Out up', 'elementor-team-vision' ),					
							'fade-out-down' 	=> esc_html__( 'Fade Out down', 'elementor-team-vision' ),					
							'fade-out-left' 	=> esc_html__( 'Fade Out Left', 'elementor-team-vision' ),					
							'fade-out-right' 	=> esc_html__( 'Fade Out Right', 'elementor-team-vision' ),
							'bounce-in'			=> esc_html__( 'Bounce In', 'elementor-team-vision' ),
							'bounce-in-up' 		=> esc_html__( 'Bounce in up', 'elementor-team-vision' ),					
							'bounce-in-down' 	=> esc_html__( 'Bounce in down', 'elementor-team-vision' ),					
							'bounce-in-left' 	=> esc_html__( 'Bounce in Left', 'elementor-team-vision' ),					
							'bounce-in-right' 	=> esc_html__( 'Bounce in Right', 'elementor-team-vision' ),					
							'bounce-out'		=> esc_html__( 'Bounce In', 'elementor-team-vision' ),
							'bounce-out-up' 	=> esc_html__( 'Bounce Out up', 'elementor-team-vision' ),					
							'bounce-out-down' 	=> esc_html__( 'Bounce Out down', 'elementor-team-vision' ),					
							'bounce-out-left' 	=> esc_html__( 'Bounce Out Left', 'elementor-team-vision' ),					
							'bounce-out-right' 	=> esc_html__( 'Bounce Out Right', 'elementor-team-vision' ),	
							'zoom-in'			=> esc_html__( 'Zoom In', 'elementor-team-vision' ),
							'zoom-in-up' 		=> esc_html__( 'Zoom in up', 'elementor-team-vision' ),					
							'zoom-in-down' 		=> esc_html__( 'Zoom in down', 'elementor-team-vision' ),					
							'zoom-in-left' 		=> esc_html__( 'Zoom in Left', 'elementor-team-vision' ),					
							'zoom-in-right' 	=> esc_html__( 'Zoom in Right', 'elementor-team-vision' ),					
							'zoom-out'			=> esc_html__( 'Zoom In', 'elementor-team-vision' ),
							'zoom-out-up' 		=> esc_html__( 'Zoom Out up', 'elementor-team-vision' ),					
							'zoom-out-down' 	=> esc_html__( 'Zoom Out down', 'elementor-team-vision' ),					
							'zoom-out-left' 	=> esc_html__( 'Zoom Out Left', 'elementor-team-vision' ),					
							'zoom-out-right' 	=> esc_html__( 'Zoom Out Right', 'elementor-team-vision' ),
							'flash' 			=> esc_html__( 'Flash', 'elementor-team-vision' ),
							'strobe'			=> esc_html__( 'Strobe', 'elementor-team-vision' ),
							'shake-x'			=> esc_html__( 'Shake X', 'elementor-team-vision' ),
							'shake-y'			=> esc_html__( 'Shake Y', 'elementor-team-vision' ),
							'bounce' 			=> esc_html__( 'Bounce', 'elementor-team-vision' ),
							'tada'				=> esc_html__( 'Tada', 'elementor-team-vision' ),
							'rubber-band'		=> esc_html__( 'Rubber Band', 'elementor-team-vision' ),
							'swing' 			=> esc_html__( 'Swing', 'elementor-team-vision' ),
							'spin'				=> esc_html__( 'Spin', 'elementor-team-vision' ),
							'spin-reverse'		=> esc_html__( 'Spin Reverse', 'elementor-team-vision' ),
							'slingshot'			=> esc_html__( 'Slingshot', 'elementor-team-vision' ),
							'slingshot-reverse'	=> esc_html__( 'Slingshot Reverse', 'elementor-team-vision' ),
							'wobble'			=> esc_html__( 'Wobble', 'elementor-team-vision' ),
							'pulse' 			=> esc_html__( 'Pulse', 'elementor-team-vision' ),
							'pulsate'			=> esc_html__( 'Pulsate', 'elementor-team-vision' ),
							'heartbeat'			=> esc_html__( 'Heartbeat', 'elementor-team-vision' ),
							'panic' 			=> esc_html__( 'Panic', 'elementor-team-vision' )				
						],
						'condition'	=> [
							'addon_animate'	=> 'on'
						]
					],
					[
						'name' => 'delay',
						'label' => esc_html__( 'Animate Delay (ms)', 'elementor-team-vision' ),
						'type' => Controls_Manager::TEXT,
						'default' => '1000',
						'condition'	=> [
							'addon_animate'	=> 'on'
						]
					]					
				],
				'title_field' => '{{{ name }}}',
			]
		);
		$this->end_controls_section();		
		
	}

	 
	 /**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		static $instance = 0;
		$instance++;		
		$settings = $this->get_settings_for_display();
	
		$columns			= esc_html($settings['columns']);
		$custom_style 		= esc_html($settings['custom_style']);
		$title_color		= esc_html($settings['title_color']);
		$role_color			= esc_html($settings['role_color']);
		$social_color		= esc_html($settings['social_color']);
		$h_color			= esc_html($settings['h_color']);
		
		wp_enqueue_style( 'fonts-vc' );
		wp_enqueue_style( 'animations' );					

		if($custom_style == 'on') :
		
			$css_style_to_append = "<style>
			.teamvision-team-style6-".esc_html($instance)." .teamvision-team-name, 
			.teamvision-team-style6-".esc_html($instance)." .teamvision-team-container-wrap span.teamvision-team-name { color:".esc_html($title_color).";}
			.teamvision-team-style6-".esc_html($instance)." .teamvision-team-container-wrap span.teamvision-team-role { color:".esc_html($role_color).";}
			.teamvision-team-style6-".esc_html($instance)." .teamvision-team-social-container a { color:".esc_html($social_color).";}
			.teamvision-team-style6-".esc_html($instance)." a:hover { color:".esc_html($h_color)."; }
			</style>";
			$data_value = 'data-teamvision-custom-css="'.$css_style_to_append.'"';
			$js_class = 'teamvision-custom-js';
		
		else :

			$js_class = $data_value = '';

		endif;
		
			echo '<div '.$data_value.' class="teamvision teamvision-team-style6 teamvision-team-col-'.esc_html($columns).' teamvision-team-style6-'.esc_html($instance).' '.esc_html($js_class).'">';
							
							
			foreach ( $settings['elements'] as $element ) {
				$team_image_array = wp_get_attachment_image_src( $element['image_user']['id'], 'teamvision-large');
				echo '<div class="teamvision-team teamvision-item-'.esc_html($instance).teamvision_animate_class($element['addon_animate'],$element['effect'],$element['delay']).'>';
					echo '<div class="teamvision-team-container" style="background-image:url('.esc_url($team_image_array[0]).');">';
								echo '<div class="teamvision-team-container-wrap">';
												
					echo '<div class="teamvision-team-social-container">';
						if($element['url_social_1']) :										
							echo '<a href="'.esc_url($element['url_social_1']).'" class="'.esc_html($element['social_icon_1']).'" target="'.esc_html($element['social_target']).'"></a>';   
						endif;
						if($element['url_social_2']) :							
							echo '<a href="'.esc_url($element['url_social_2']).'" class="'.esc_html($element['social_icon_2']).'" target="'.esc_html($element['social_target']).'"></a>';   
						endif;
						if($element['url_social_3']) :			
							echo '<a href="'.esc_url($element['url_social_3']).'" class="'.esc_html($element['social_icon_3']).'" target="'.esc_html($element['social_target']).'"></a>';
						endif;
						if($element['url_social_4']) :			
							echo '<a href="'.esc_url($element['url_social_4']).'" class="'.esc_html($element['social_icon_4']).'" target="'.esc_html($element['social_target']).'"></a>';
						endif;
						if($element['url_social_5']) :			
							echo '<a href="'.esc_url($element['url_social_5']).'" class="'.esc_html($element['social_icon_5']).'" target="'.esc_html($element['social_target']).'"></a>';
						endif;	
					echo '</div>';		
					echo '</div></div>
							<span class="teamvision-team-name">'.esc_html($element['name']).'</span>
							<span class="teamvision-team-role">'.esc_html($element['role']).'</span>					
					</div>';							
			}

			echo '<div class="teamvision-clear"></div></div>';
		
	}

	/**
	 * Render the widget output in the editor.
	 *
	 * Written as a Backbone JavaScript template and used to generate the live preview.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function _content_template() {}
}
